"""
"manipulations and lies"

🚯 About
--------

Manipulate simple configuration files in a, relatively, intelligent fashion.

Given a simple configuration file, :py:mod:`cofman.lib` provides a means to edit the file
using a dictionary-like interface::

	import cofman.lib

	config = cofman.lib.File("/etc/sysctl.conf")
	>>> config['kern.sysv.shmmin']
	"1"
	# given permission =)
	>>> config['kern.sysv.shmmin'] = "100"
	"100"

Every dictionary operation reads from the file, so using this as a cache is not
appropriate. Usually, only the :py:meth:`cofman.lib.File.update` and
:py:meth:`cofman.lib.File.getset` methods should be used to interact with the
configuration. The other operations are provided for convenience.

By default, the configuration file is assumed to use the following delimiters::

	config = {
		'quote': "'",
		'quote_escape': "''",
		'comment': "#",
		'assignment': '=',
		'record': '\\n',
	}

.. warning:: The value side of the settings are unconditionally quoted when modified.

Considerations
--------------

cofman was not written with performance in mind. It is designed for common case editing
that does not occur often enough to warrant heavy optimizations.
"""
__pkg_bottom__ = True
